@@ -36,6 +36,9 @@ Released under GNU AGPLv3.
         parser_odoo = subparsers.add_parser(
             'odoo', help="Run Odoo server normally.",
             parents=[parser_shared, parser_shared])
+        parser_odoo.add_argument(
+            "-t", "--test", dest="odoo_test", action="store_true",
+            help="Run with test configuration.")
         parser_odoo.add_argument(
             "-u", "--update", dest="odoo_update",
             nargs='?', metavar='all|<module1>[,<module2>…]',
@@ -76,5 +79,10 @@ Released under GNU AGPLv3.
             help="Drop used database before exiting.")
         parser_i18n_export.set_defaults(func="i18n-export")
 
+        parser_project_dist = subparsers.add_parser(
+            'project.dist', help="Generate the distribution artifacts",
+            parents=[parser_shared])
+        parser_project_dist.set_defaults(func="project-dist")
+
         argcomplete.autocomplete(parser)
         self.args, self.odoo_args = parser.parse_known_args()
